==> vagrant-2.0.3.tar.gz: vagrant-2.0.3/website/source/vmware/reseller.html.md <==
---
layout: "vmware"
sidebar_current: "vmware-reseller"
page_title: "Reseller Information - VMware Plugin"
description: |-
  This page is intended to answer questions commonly needed by resellers. If you
  are a reseller all required information should be on this page.
---

# Reseller Information

We are happy to work with resellers for the Vagrant VMware provider.

This page is intended to answer questions commonly needed by resellers. If you
are a reseller all required information should be on this page.

## Reseller Discounts

We do not offer reseller discounts. Volume pricing is available for those who
qualify.

## Volume Pricing

We offer volume pricing when purchasing more than 150 licenses. If you or your
organization plans to purchase more than 150 license seats, please contact
sales@hashicorp.com to learn more about volume discounts before making your
purchase.

## Quote

Each license is a one-time cost of $79 USD per seat. All orders must be placed
using US currency.

## VMware Workstation vs. VMware Fusion

The Vagrant VMware Workstation and Vagrant VMware Fusion licenses are separate
products. While they share the same price, they have a different license and
different product SKUs. Please note that the purchase of the license does not
include the VMware software itself.

## Purchase Orders

Although we prefer the self-serve purchase, you may email us a complete
PO (with credit card information included) to sales@hashicorp.com. We
will then process your order. **The minimum quantity for purchase orders is 50
licenses!**

All purchase orders must include the following:

1. Billing address
1. Billing phone number
1. Credit card number
1. CCV number

The following product SKUs are available:

- `HCVAVFD` - Vagrant VMware Fusion Plugin (8+)
- `HCVAVWD` - Vagrant VMware Workstation Plugin (12+)

Failure to include all required information or proper product SKUs may result in
delayed processing.

You are responsible for license distribution to the end user. HashiCorp will
provide you with a downloadable license file and instructions, but it is the
reseller's responsibility to distribute to the customer.

## Seats

A single seat can be used on two computers (such as a desktop and a laptop)
for a single person. The license is valid forever with access to free
maintenance updates.

## Upgrade Pricing &amp; Eligibility

Future major updates may require an upgrade fee. Typically this upgrade fee is
$49 USD, but that is subject to change. Customers may check their license
upgrade eligibility by visiting the
[license upgrade center](http://license.hashicorp.com/upgrade/vmware2015) and
entering the email address with which they made the purchase. For licenses
purchased by a reseller, only the reseller can request the license upgrade.

## Licenses

After a successful purchase, license files and associated installation
instructions will be generated and emailed to you.

## Company Details

Business name:

    HashiCorp, Inc.

Business website and support:

    www.hashicorp.com
    support@hashicorp.com

Our current registered business address is:

    101 2nd Street #575
    San Francisco, CA 94105

==> vagrant-2.1.5.tar.gz: vagrant-2.1.5/website/source/vmware/reseller.html.md <==
---
layout: "vmware"
sidebar_current: "vmware-reseller"
page_title: "Reseller Information - VMware Plugin"
description: |-
  This page is intended to answer questions commonly needed by resellers. If you
  are a reseller all required information should be on this page.
---

# Reseller Information

We are happy to work with resellers for the Vagrant VMware provider.

This page is intended to answer questions commonly needed by resellers. If you
are a reseller all required information should be on this page.

## Reseller Discounts

We do not offer reseller discounts. Volume pricing is available for those who
qualify.

## Volume Pricing

We offer volume pricing when purchasing 1 or more sets of 150 licenses. If you
or your organization plans to purchase 1 or more sets of 150 licenses, please
contact sales@hashicorp.com to learn more about volume discounts before making your
purchase.

## Quote

Each license is a one-time cost of $79 USD per seat. All orders must be placed
using US currency.

## Self-serve purchase

Licenses can be purchased in our [self service portal](http://www.vagrantup.com/vmware#buy-now)
with a credit card.

## Purchase Orders

Although we prefer the self-serve purchase, for 1 or more sets of 150 licenses, we
can do PO. Please contact sales@hashicorp.com for a quote.

The following product SKU is available:

- `HCVAVDA` - Vagrant VMware Desktop Plugin

Failure to include all required information or proper product SKUs may result in
delayed processing.

You are responsible for license distribution to the end user. HashiCorp will
provide you with a downloadable license file and instructions, but it is the
reseller's responsibility to distribute to the customer.

## Seats

A single seat can be used on two computers (such as a desktop and a laptop)
for a single person. The license is valid forever with access to free
maintenance updates.

## Upgrade Pricing &amp; Eligibility

Future major updates may require an upgrade fee. Typically this upgrade fee is
$49 USD, but that is subject to change. Customers may check their license
upgrade eligibility by visiting the
[license upgrade center](http://license.hashicorp.com/upgrade/vmware2015) and
entering the email address with which they made the purchase. For licenses
purchased by a reseller, only the reseller can request the license upgrade.

## Licenses

After a successful purchase, license files and associated installation
instructions will be generated and emailed to you.

## Company Details

Business name:

    HashiCorp, Inc.

Business website and support:

    www.hashicorp.com
    support@hashicorp.com

Our current registered business address is:

    101 2nd Street #575
    San Francisco, CA 94105
